@@ -46,6 +46,13 @@ class TflAppMain(QtGui.QMainWindow):
         QtGui.QDesktopServices.openUrl(QtCore.QUrl(finalUrl, QtCore.QUrl.TolerantMode))
 
     def getCurrentPCode(self):
+        self.getCurrentLoc()
+        pCode = self.getCurrentPCodeFromLoc()
+        os.popen('dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:"NOT FULLY IMPLEMENTED - Just a test route for now"')
+
+        return pCode
+
+    def getCurrentLoc(self):
         control = location.GPSDControl.get_default()
         device = location.GPSDevice()
         control.set_properties(preferred_method=location.METHOD_ACWP,
@@ -60,12 +67,10 @@ class TflAppMain(QtGui.QMainWindow):
 
         self.loop.run()
 
-        os.popen('dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:"NOT FULLY IMPLEMENTED - Just a test route for now"')
-
 
+    def getCurrentPCodeFromLoc(self):
         return "NW1 2DB"
 
-
     def showTubeMap(self):
         self.tubemap.setupWindow()
         self.tubemap.show()
